@@ -61,12 +61,12 @@
                    "nodeHarvest", "Linda", "QdaCov", "stepLDA", "stepQDA",
                    "parRF", "plr", "rocc", "foba", "partDSA", "hda", "icr", "Boruta",
                    "plsGlmBinomial", "plsGlmGaussian", "plsGlmGamma", "plsGlmPoisson",
-                   "bstTree", 'bstLs', 'bstSm', 'avNNet',
+                   "bstTree", 'bstLs', 'bstSm', 'avNNet', 'ridge',
                    "qrf", "scrda", "bag", "hdda", "logreg", "logforest", "logicBag", "qrnn"))
     {
       trainX <- data[,!(names(data) %in% ".outcome"), drop = FALSE]
       trainY <- data[,".outcome"]
-      if(!is.null(pp))
+      if(!is.null(pp$options))
         {
           pp$x <- trainX
           ppObj <- do.call("preProcess", pp)
@@ -76,7 +76,7 @@
           data$.outcome <- trainY
         } else ppObj <- NULL
     } else {
-      if(!is.null(pp))
+      if(!is.null(pp$options))
         {
           y <- data$.outcome
           data$.outcome <- NULL
@@ -586,8 +586,26 @@
                      bagEarth =
                      {
                        library(earth)
-                       bagEarth(trainX, trainY, degree = tuneValue$.degree,
-                                nprune = tuneValue$.nprune, ...)
+                       
+                       #glmVal <- if(type == "Classification") list(family=binomial) else NULL
+                       #bagEarth(trainX, trainY, degree = tuneValue$.degree,
+                       #         glm = glmVal,
+                       #         nprune = tuneValue$.nprune, ...)
+                       theDots <- list(...)
+                       theDots$keepxy <- TRUE 
+                       
+                       modelArgs <- c(
+                                      list(
+                                           x = trainX,
+                                           y = trainY,
+                                           degree = tuneValue$.degree),
+                                      theDots)
+                       if(type == "Classification") modelArgs$glm <- list(family=binomial)
+                       
+                       tmp <- do.call("bagEarth", modelArgs)
+
+                       tmp$call["degree"] <-  tuneValue$.degree
+                       tmp
                      },
                      
                      bagFDA =
@@ -897,11 +915,11 @@
                        
                        theDots <- list(...)
                        
-                       if(any(names(theDots) == "control"))
+                       if(any(names(theDots) == "controls"))
                          {
-                           theDots$control@gtctrl@mtry <- as.integer(tuneValue$.mtry) 
-                           ctl <- theDots$control
-                           theDots$control <- NULL
+                           theDots$controls@gtctrl@mtry <- as.integer(tuneValue$.mtry) 
+                           ctl <- theDots$controls
+                           theDots$controls <- NULL
                            
                          } else ctl <- cforest_control(mtry = tuneValue$.mtry)
                        
@@ -912,13 +930,13 @@
                                       list(
                                            formula = modFormula,
                                            data = data,
-                                           control = ctl),
+                                           controls = ctl),
                                       theDots)
                        
                        out <- do.call("cforest", modelArgs)
                        out        
                      },
-                     enet =, lasso =
+                     enet =, lasso =, ridge =
                      {
                        library(elasticnet)
                        lmbda <- if(method == "lasso") 0 else tuneValue$.lambda
@@ -1385,7 +1403,6 @@
                      },
                      parRF =
                      {
-                       library(foreach)
                        library(randomForest)
                        
                        workers <- getDoParWorkers()
